---
title: Installing Infrahub sync
---

Infrahub Sync is available on [PyPI](https://pypi.org/project/infrahub-sync/) and can be installed using the pip package installer. It is recommended to install the Sync into a virtual environment.

```bash
python3 -m venv .venv
source .venv/bin/activate
pip install infrahub-sync
```
